#
# spec file for package python-PyMySQL
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-PyMySQL
Version:        0.9.3
Release:        2.1
Summary:        Pure Python MySQL Driver
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/PyMySQL/PyMySQL/
Source:         https://files.pythonhosted.org/packages/source/P/PyMySQL/PyMySQL-%{version}.tar.gz
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
# will be removed with next release
BuildRequires:  %{python_module unittest2}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cryptography
BuildArch:      noarch
%python_subpackages

%description
This package contains a pure-Python MySQL client library. Documentation on the
MySQL client/server protocol can be found here:
http://forge.mysql.com/wiki/MySQL_Internals_ClientServer_Protocol

The goal of pymysql is to be a drop-in replacement for MySQLdb and work on
CPython 2.3+, Jython, IronPython, PyPy and Python 3. We test for compatibility
by simply changing the import statements in the Django MySQL backend and running
its unit tests as well as running it against the MySQLdb and myconnpy unit tests.

%prep
%setup -q -n PyMySQL-%{version}
# remove unwanted shebang
sed -i '1 { /^#!/ d }' pymysql/tests/thirdparty/test_MySQLdb/*.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Needs mysql server
#%%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} py.test-%{$python_bin_suffix} -v

%files %{python_files}
%license LICENSE
%doc CHANGELOG README.rst
%{python_sitelib}/*

%changelog
* Wed Mar  6 2019 tchvatal@suse.com
- Update to 0.9.3:
  * cryptography dependency is optional now.
  * Fix old_password (used before MySQL 4.1) support.
  * Deprecate old_password.
  * Stop sending ``sys.argv[0]`` for connection attribute "program_name".
  * Close connection when unknown error is happened.
  * Deprecate context manager API of Connection object.
  * Disalbled unintentinally enabled debug log
  * Removed unintentionally installed tests
  * Fixed caching_sha2_password and sha256_password raise TypeError on PY2
    (#700, #702)
  * Change default charset from latin1 to utf8mb4.  (because MySQL 8 changed) (#692)
  * Support sha256_password and caching_sha2_password auth method (#682)
  * Add cryptography dependency, because it's needed for new auth methods.
  * Remove deprecated `no_delay` option (#694)
  * Support connection attributes (#679)
  * Map LOCK_DEADLOCK to OperationalError (#693)
* Thu May 24 2018 tchvatal@suse.com
- Drop not really needed python-devel dependency
* Thu May 24 2018 kukuk@suse.de
- use %%license instead of %%doc [bsc#1082318]
- update to latest version to solve MySQLdb interface problems with
  salt-2018
- update to 0.8.1
  * Reduce `cursor.callproc()` roundtrip time. (#636)
  * Fixed `cursor.query()` is hunged after multi statement failed. (#647)
  * WRONG_DB_NAME and WRONG_COLUMN_NAME is ProgrammingError for now. (#629)
  * Many test suite improvements, especially adding MySQL 8.0 and using Docker.
  * Droppped support for old Python and MySQL whih is not tested long time.
- update to 0.8
  * **BACKWARD INCOMPATIBLE** ``binary_prefix`` option is added and off
  by default because of compatibility with mysqlclient.
  When you need PyMySQL 0.7 behavior, you have to pass ``binary_prefix=True``.
  (#549)
  * **BACKWARD INCOMPATIBLE** ``MULTI_STATEMENTS`` client flag is no longer
  set by default, while it was on PyMySQL 0.7.  You need to pass
  ``client_flag=CLIENT.MULTI_STATEMENTS`` when you connect to explicitly
  enable multi-statement mode. (#590)
  * Fixed AuthSwitch packet handling.
  * Raise OperationalError for MariaDB's constraint error. (#607)
  * executemany() accepts query without space between ``VALUES`` and ``(``.  (#597)
  * Support config file containing option without value. (#588)
  * Fixed Connection.ping() returned unintended value.
* Wed Aug 16 2017 toddrme2178@gmail.com
- Implement single-spec version
- update to 0.7.11
  * Fixed Connection.close() failed when failed to send COM_CLOSE packet.
  * Cursor.executemany() accepts query ends with semicolon.
  * ssl parameters can be read from my.cnf.
- update to 0.7.10
  * **SECURITY FIX**: Raise RuntimeError when received LOAD_LOCAL packet while
    ``loacal_infile=False``.  (Thanks to Bryan Helmig)
  * Raise SERVER_LOST error for MariaDB's shutdown packet (#540)
  * Change default connect_timeout to 10.
  * Add bind_address option (#529)
- update to 0.7.9
  * Fix PyMySQL stop reading rows when first column is empty string (#513)
    Reverts DEPRECATE_EOF introduced in 0.7.7.
- update to 0.7.8
  * Revert error message change in 0.7.7.
    (SQLAlchemy parses error message, #507)
- update to 0.7.7
  * Add new unicode collation (#498)
  * Fix conv option is not used for encoding objects.
  * Experimental support for DEPRECATE_EOF protocol.
* Tue Nov 15 2016 dmueller@suse.com
- update to 0.7.6:
  * Fix SELECT JSON type cause UnicodeError
  * Avoid float convertion while parsing microseconds
  * Warning has number
  * SSCursor supports warnings
  * Fix exception raised while importing when getpwuid() fails (#472)
  * SSCursor supports LOAD DATA LOCAL INFILE (#473)
  * Fix encoding error happen for JSON type (#477)
  * Fix test fail on Python 2.7 and MySQL 5.7 (#478)
* Fri Jun  3 2016 tbechtold@suse.com
- update to 0.7.4:
  * Fix AttributeError may happen while Connection.__del__ (#463)
  * Fix SyntaxError in test_cursor. (#464)
  * frozenset support for query value. (#461)
  * Start using readthedocs.io
  * Add read_timeout and write_timeout option.
  * Support serialization customization by `conv` option.
  * Unknown type is converted by `str()`, for MySQLdb compatibility.
  * Support '%%%%' in `Cursor.executemany()`
  * Support REPLACE statement in `Cursor.executemany()`
  * Fix handling incomplete row caused by 'SHOW SLAVE HOSTS'.
  * Fix decode error when use_unicode=False on PY3
  * Fix port option in my.cnf file is ignored.
* Thu Mar 24 2016 toddrme2178@gmail.com
- Add license and docs
* Thu Mar 24 2016 toddrme2178@gmail.com
- Update to 0.7.2
  * Fix misuse of `max_allowed_packet` parameter. (#426, #407 and #397)
  * Add %%(name)s plceholder support to `Cursor.executemany()`. (#427, thanks to
    @WorldException)
- Update to 0.7.1
  * Fix auth fail with MySQL 5.1
  * Fix escaping unicode fails on Python 2
- Update to 0.7
  * Faster binary escaping
  * Add `"_binary" prefix` to string literal for binary types.
    binary types are: `bytearray` on Python 2, `bytes` and `bytearray` on Python 3.
    This is because recent MySQL show warnings when string literal is invalid for
    connection encoding.
  * `pymysql.Binary()` returns `bytearray` on Python 2.  This is required to distinguish
    binary and string.
  * Auth plugin support.
  * no_delay option is ignored.  It will be removed in PyMySQL 0.8.
- Update to 0.6.7
  * Allow self signed certificate
  * Add max_allowed_packet option
  * Fix error when bytes in executemany
  * Support geometry type
  * Add coveralls badge to README
  * Fix some bugs relating to warnings
  * Add Cursor.mogrify() method
  * no_delay option is deprecated and True by default
  * Fix options from my.cnf overrides options from arguments
  * Allow socket like object.  (It's not feature for end users)
  * Strip quotes while reading options from my.cnf file
  * Fix encoding issue in executemany()
* Mon May 11 2015 benoit.monin@gmx.fr
- update to version 0.6.6:
    Add context manager to cursor
  * Fix can't encode blob that is not utf-8 on PY3. (regression of
    0.6.4, Thanks to @wiggzz)
- additional changes from version 0.6.4
  * Support "LOAD LOCAL INFILE".  Thanks @wraziens
  * Show MySQL warnings after execute query.
  * Fix MySQLError may be wrapped with OperationalError while
    connectiong. (#274)
  * SSCursor no longer attempts to expire un-collected rows within
    __del__, delaying termination of an interrupted program;
    cleanup of uncollected rows is left to the Connection on next
    execute, which emits a warning at that time. (#287)
  * Support datetime and time with microsecond. (#303)
  * Use surrogateescape to format bytes on Python 3.
  * OperationalError raised from connect() have information about
    original exception. (#304)
  * `init_command` now support multi statement.
  * `Connection.escape()` method now accepts second argument
    compatible to MySQL-Python.
- additional changes from version 0.6.3
  * Fixed multiple result sets with SSCursor.
  * Fixed connection timeout.
  * Fixed literal set syntax to work on Py2.6.
  * Allow for mysql negative values with 0 hour timedelta.
  * Added Connection.begin().
- additional changes from version 0.6.2
  * Fixed old password on Python 3.
  * Added support for bulk insert in Cursor.executemany().
  * Added support for microseconds in datetimes and dates before
    1900.
  * Several other bug fixes.
- additional changes from version 0.6.1
  * Added cursor._last_executed for MySQLdb compatibility
  * Cursor.fetchall() and .fetchmany now return list, not tuple
  * Allow "length of auth-plugin-data" = 0
  * Cursor.connection references connection object without weakref
- remove unwanted shebang of python files in test_MySQLdb
* Wed Oct  9 2013 dmueller@suse.com
- update to 0.6:
  - Improved Py3k support
  - Improved PyPy support
  - Added IPv6 support
  - Added Thing2Literal for Django/MySQLdb compatibility
  - Removed errorhandler
  - Fixed GC errors
  - Improved test suite
  - Many bug fixes
  - Many performance improvements
* Mon Jul 22 2013 speilicke@suse.com
- Initial version
